@@ -1,17 +1,15 @@
 """SatNOGS DB API serializers, django rest framework"""
 #  pylint: disable=R0201
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
 
+import h5py
 from rest_framework import serializers
 
-from db.base.models import TRANSMITTER_STATUS, DemodData, Mode, Satellite, \
-    Telemetry, Transmitter
+from db.base.models import TRANSMITTER_STATUS, Artifact, DemodData, Mode, \
+    Satellite, Telemetry, Transmitter
 
 
 class ModeSerializer(serializers.ModelSerializer):
     """SatNOGS DB Mode API Serializer"""
-
     class Meta:
         model = Mode
         fields = ('id', 'name')
@@ -19,7 +17,6 @@ class ModeSerializer(serializers.ModelSerializer):
 
 class SatTelemetrySerializer(serializers.ModelSerializer):
     """SatNOGS DB satellite telemetry API Serializer"""
-
     class Meta:
         model = Telemetry
         fields = ['decoder']
@@ -29,10 +26,23 @@ class SatelliteSerializer(serializers.ModelSerializer):
     """SatNOGS DB Satellite API Serializer"""
 
     telemetries = SatTelemetrySerializer(many=True, read_only=True)
+    countries = serializers.SerializerMethodField()
+    operator = serializers.SerializerMethodField()
 
     class Meta:
         model = Satellite
-        fields = ('norad_cat_id', 'name', 'names', 'image', 'status', 'decayed', 'telemetries')
+        fields = (
+            'norad_cat_id', 'name', 'names', 'image', 'status', 'decayed', 'launched', 'deployed',
+            'website', 'operator', 'countries', 'telemetries'
+        )
+
+    def get_operator(self, obj):
+        """Returns operator text"""
+        return str(obj.operator)
+
+    def get_countries(self, obj):
+        """Returns countires"""
+        return ','.join(map(str, obj.countries))
 
 
 class TransmitterSerializer(serializers.ModelSerializer):
@@ -124,7 +134,36 @@ class TelemetrySerializer(serializers.ModelSerializer):
 
 class SidsSerializer(serializers.ModelSerializer):
     """SatNOGS DB SiDS API Serializer"""
-
     class Meta:
         model = DemodData
         fields = ('satellite', 'payload_frame', 'station', 'lat', 'lng', 'timestamp', 'app_source')
+
+
+class ArtifactSerializer(serializers.ModelSerializer):
+    """SatNOGS DB Artifacts API Serializer"""
+    class Meta:
+        model = Artifact
+        fields = ('id', 'network_obs_id', 'artifact_file')
+
+
+class NewArtifactSerializer(serializers.ModelSerializer):
+    """SatNOGS Network New Artifact API Serializer"""
+    def validate(self, attrs):
+        """Validates data of incoming artifact"""
+
+        try:
+            with h5py.File(self.initial_data['artifact_file'], 'r') as h5_file:
+                if 'artifact_version' not in h5_file.attrs:
+                    raise serializers.ValidationError(
+                        'Not a valid SatNOGS Artifact.', code='invalid'
+                    )
+        except OSError as error:
+            raise serializers.ValidationError(
+                'Not a valid HDF5 file: {}'.format(error), code='invalid'
+            )
+
+        return attrs
+
+    class Meta:
+        model = Artifact
+        fields = ('artifact_file', )
