@@ -1,10 +1,9 @@
 """Miscellaneous functions for SatNOGS DB"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 import binascii
 import logging
+import math
 from datetime import datetime, timedelta
+from decimal import Decimal
 
 from django.conf import settings
 from django.core.cache import cache
@@ -303,12 +302,17 @@ def cache_statistics():
     statistics = calculate_statistics()
     cache.set('stats_transmitters', statistics, 60 * 60 * 2)
 
+    ids = Satellite.objects.values('id')
+    cache.set('satellites_ids', ids, 60 * 60 * 2)
+
     satellites = Satellite.objects \
-                          .values('name', 'norad_cat_id') \
+                          .values('name', 'norad_cat_id', 'id') \
                           .annotate(count=Count('telemetry_data'),
                                     latest_payload=Max('telemetry_data__timestamp')) \
                           .order_by('-count')
-    cache.set('stats_satellites', satellites, 60 * 60 * 2)
+
+    for sat in satellites:
+        cache.set(sat['id'], sat, 60 * 60 * 2)
 
     observers = DemodData.objects \
                          .values('observer') \
@@ -316,3 +320,55 @@ def cache_statistics():
                                    latest_payload=Max('timestamp')) \
                          .order_by('-count')
     cache.set('stats_observers', observers, 60 * 60 * 2)
+
+
+def remove_exponent(converted_number):
+    """Remove exponent."""
+    return converted_number.quantize(
+        Decimal(1)
+    ) if converted_number == converted_number.to_integral() else converted_number.normalize()
+
+
+def millify(number, precision=0):
+    """Humanize number."""
+    millnames = ['', 'k', 'M', 'B', 'T', 'P', 'E', 'Z', 'Y']
+    number = float(number)
+    millidx = max(
+        0,
+        min(
+            len(millnames) - 1, int(math.floor(0 if number == 0 else math.log10(abs(number)) / 3))
+        )
+    )
+    result = '{:.{precision}f}'.format(number / 10**(3 * millidx), precision=precision)
+    result = remove_exponent(Decimal(result))
+    return '{0}{dx}'.format(result, dx=millnames[millidx])
+
+
+def read_influx(norad):
+    """Queries influxdb for the last 30d of data points (counted) in 1d resolution.
+
+    :param norad: the NORAD ID of the satellite to query influxdb for
+    :returns: a raw json of the measurement, timestamps, and point counts
+    """
+    client = InfluxDBClient(
+        settings.INFLUX_HOST,
+        settings.INFLUX_PORT,
+        settings.INFLUX_USER,
+        settings.INFLUX_PASS,
+        settings.INFLUX_DB,
+        ssl=settings.INFLUX_SSL,
+        verify_ssl=settings.INFLUX_VERIFY_SSL
+    )
+
+    # check against injection
+    if isinstance(norad, int):
+        # epoch:s to set the return timestamp in unixtime for easier conversion
+        params = {'epoch': 's'}
+        results = client.query(
+            'SELECT count(*) FROM "' + str(norad) +
+            '" WHERE time > now() - 30d GROUP BY time(1d) fill(null)',
+            params=params
+        )
+        return results.raw
+    # no-else-return
+    return ''
