@@ -4,9 +4,6 @@ For local installation settings please copy .env-dist to .env and edit
 the appropriate settings in that file. You should not need to edit this
 file for local settings!
 """
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 import sentry_sdk
 from decouple import Csv, config
 from dj_database_url import parse as db_url
@@ -33,9 +30,13 @@ DJANGO_APPS = (
 )
 THIRD_PARTY_APPS = (
     'avatar',
+    'bootstrap_modal_forms',
     'rest_framework',
     'rest_framework.authtoken',
+    'django_countries',
     'django_filters',
+    'fontawesome_5',
+    'widget_tweaks',
     'allauth',
     'allauth.account',
     'allauth.socialaccount',
@@ -132,7 +133,9 @@ TEMPLATES = [
                 'django.template.context_processors.request',
                 'db.base.context_processors.analytics', 'db.base.context_processors.stage_notice',
                 'db.base.context_processors.auth_block', 'db.base.context_processors.logout_block',
-                'db.base.context_processors.version', 'db.base.context_processors.decoders_version'
+                'db.base.context_processors.version',
+                'db.base.context_processors.decoders_version',
+                'db.base.context_processors.login_button'
             ],
             'loaders': [
                 (
@@ -160,14 +163,17 @@ STATICFILES_FINDERS = (
 MEDIA_ROOT = config('MEDIA_ROOT', default=Path('media').resolve())
 FILE_UPLOAD_TEMP_DIR = config('FILE_UPLOAD_TEMP_DIR', default=Path('/tmp').resolve())
 MEDIA_URL = config('MEDIA_URL', default='/media/')
-CRISPY_TEMPLATE_PACK = 'bootstrap3'
-SATELLITE_DEFAULT_IMAGE = '/static/img/sat.png'
+CRISPY_TEMPLATE_PACK = 'bootstrap4'
+SATELLITE_DEFAULT_IMAGE = '/static/img/sat_purple.png'
 COMPRESS_ENABLED = config('COMPRESS_ENABLED', default=False, cast=bool)
 COMPRESS_OFFLINE = config('COMPRESS_OFFLINE', default=False, cast=bool)
 COMPRESS_CACHE_BACKEND = config('COMPRESS_CACHE_BACKEND', default='default')
-COMPRESS_CSS_FILTERS = [
-    'compressor.filters.css_default.CssAbsoluteFilter', 'compressor.filters.cssmin.rCSSMinFilter'
-]
+COMPRESS_FILTERS = {
+    'css': [
+        'compressor.filters.css_default.CssAbsoluteFilter',
+        'compressor.filters.cssmin.rCSSMinFilter'
+    ]
+}
 
 # App conf
 ROOT_URLCONF = 'db.urls'
@@ -262,7 +268,10 @@ REDIS_CONNECT_RETRY = True
 REST_FRAMEWORK = {
     'DEFAULT_PERMISSION_CLASSES':
     ('rest_framework.permissions.DjangoModelPermissionsOrAnonReadOnly', ),
-    'DEFAULT_AUTHENTICATION_CLASSES': ('rest_framework.authentication.TokenAuthentication', ),
+    'DEFAULT_AUTHENTICATION_CLASSES': [
+        'rest_framework.authentication.TokenAuthentication',
+        'rest_framework.authentication.SessionAuthentication'
+    ],
     'DEFAULT_FILTER_BACKENDS': ('django_filters.rest_framework.DjangoFilterBackend', )
 }
 
@@ -273,14 +282,20 @@ CSP_DEFAULT_SRC = config(
     'CSP_DEFAULT_SRC',
     cast=lambda v: tuple(s.strip() for s in v.split(',')),
     default="'self',"
-    'https://*.mapbox.com'
+    'https://*.mapbox.com,'
+    'https://kit-free.fontawesome.com,'
+    'https://ka-f.fontawesome.com,'
+    'https://fonts.gstatic.com,'
+    "'unsafe-inline'"
 )
 CSP_SCRIPT_SRC = config(
     'CSP_SCRIPT_SRC',
     cast=lambda v: tuple(s.strip() for s in v.split(',')),
     default="'self',"
     'https://*.google-analytics.com,'
-    "'unsafe-eval'"
+    'https://kit-free.fontawesome.com,'
+    'https://kit.fontawesome.com,'
+    "'sha256-wMIRCqWVu9YgOwizZzrYvTWAiAn0Y8PQTRdiHy2BNRk=',"  # transmitter_modal.js
 )
 CSP_IMG_SRC = config(
     'CSP_IMG_SRC',
@@ -292,6 +307,15 @@ CSP_IMG_SRC = config(
     'data:,'
     'blob:'
 )
+CSP_FRAME_SRC = config(
+    'CSP_FRAME_SRC', cast=lambda v: tuple(s.strip() for s in v.split(',')), default='blob:'
+)
+CSP_WORKER_SRC = config(
+    'CSP_WORKER_SRC',
+    cast=lambda v: tuple(s.strip() for s in v.split(',')),
+    default="'self',"
+    'blob:'
+)
 CSP_CHILD_SRC = config(
     'CSP_CHILD_SRC', cast=lambda v: tuple(s.strip() for s in v.split(',')), default='blob:'
 )
